==> annotate_1.12.1.tar.gz: annotate/R/getData.R <==
##copyright 2002 R. Gentleman, all rights reserved
##helper functions for dealing with data environments (soon to be hash
##tables)

## JZ added lookUp and modified the other functions so that they all
## use lookUp. Nov. 6, 2003.
lookUp <- function(x, data, what){
    if(length(x) < 1){
        stop("No key(s) provided")
    }
    require(data, quietly = TRUE, character.only = TRUE) ||
        stop(paste("Data package", data, "not available"))
    if(!any(ls(match(paste("package:", data, sep = ""),
                     search())) == paste(data, what, sep = ""))){
        stop(paste(what, "is an invalid element name"))
    }
    ##FIXME: we need to do the same think in all cases
    ##  so we should drop the special case here
    ## if(length(x) == 1){
    ##    mapping <- get(paste(data, what, sep = ""))[[x]]
    ## }else{
        mapping <- mget(x, env=get(paste(data, what, sep="")),
                        ifnotfound=NA)
    ##}
    return(mapping)
}

getGO <- function(x, data) {
    lookUp(x, data, "GO")
 }

 getGOdesc <- function(x, which = c("BP", "CC", "MF", "ANY")) {
     require("GO") || stop("need the GO library")
     which <- match.arg(which)
     options(show.error.messages = FALSE)
     ans <- try(lookUp(x, "GO", "TERM"))
     options(show.error.messages = TRUE)
     onts <- sapply(ans, Ontology)
     if(inherits(ans, "try-error")){
         warning(paste("Invalid GO term", x))
         return(NULL)
     }else{
         if(which == "ANY"){
             return(ans)
         }else{
             ans <- ans[onts %in% which]
             if(length(ans) == 0){
                 return(NULL)
             }else{
                 return(ans)
             }
         }
     }
 }

  getSYMBOL <- function(x, data) {
      unlist(lookUp(x, data, "SYMBOL"))
 }

  getPMID <- function(x, data) {
      lookUp(x, data, "PMID")
  }

  getLL <- function(x, data) {
      unlist(lookUp(x, data, "ENTREZID"))
  }


installDataPackage <- function(pkga, liba=.libPaths()[1]) {
    .Defunct("install.packages")
}

# This function needs to be updated when new annotation items are
# added to the data packages
getUniqAnnItem <- function(){
    return(c("ACCNUM", "ENTREZID", "GENENAME", "SYMBOL", "MAP",
             "GRIF", "SUMFUNC", "NM", "NP"))
}

==> annotate_1.14.1.tar.gz: annotate/R/getData.R <==
##copyright 2002 R. Gentleman, all rights reserved
##helper functions for dealing with data environments (soon to be hash
##tables)

## JZ added lookUp and modified the other functions so that they all
## use lookUp. Nov. 6, 2003.
lookUp <- function(x, data, what) {
    if(length(x) < 1){
        stop("No keys provided")
    }
    mget(x, envir=get(paste(data, what, sep="")),
         ifnotfound=NA)
}

getGO <- function(x, data) {
    lookUp(x, data, "GO")
 }

 getGOdesc <- function(x, which = c("BP", "CC", "MF", "ANY")) {
     require("GO") || stop("need the GO library")
     which <- match.arg(which)
     options(show.error.messages = FALSE)
     ans <- try(lookUp(x, "GO", "TERM"))
     options(show.error.messages = TRUE)
     onts <- sapply(ans, Ontology)
     if(inherits(ans, "try-error")){
         warning(paste("Invalid GO term", x))
         return(NULL)
     }else{
         if(which == "ANY"){
             return(ans)
         }else{
             ans <- ans[onts %in% which]
             if(length(ans) == 0){
                 return(NULL)
             }else{
                 return(ans)
             }
         }
     }
 }

  getSYMBOL <- function(x, data) {
      unlist(lookUp(x, data, "SYMBOL"))
 }

  getPMID <- function(x, data) {
      lookUp(x, data, "PMID")
  }

  getLL <- function(x, data) {
      unlist(lookUp(x, data, "ENTREZID"))
  }


installDataPackage <- function(pkga, liba=.libPaths()[1]) {
    .Defunct("install.packages")
}

# This function needs to be updated when new annotation items are
# added to the data packages
getUniqAnnItem <- function(){
    return(c("ACCNUM", "ENTREZID", "GENENAME", "SYMBOL", "MAP",
             "GRIF", "SUMFUNC", "NM", "NP"))
}
